@@ -103,6 +103,7 @@ class _ChunksUploader:
         file_path: str,
         endpoint: str,
         api_key: str,
+        project_id: int,
         chunk_size: int = DEFAULT_UPLOAD_CHUNK_SIZE,
         file_name: str = None,
         origin_dir_name: str = None,
@@ -113,6 +114,7 @@ class _ChunksUploader:
         self._origin_dir_name = origin_dir_name
         self._api_key = api_key
         self._endpoint = endpoint
+        self._project_id = project_id
         self._chunker = _Chunker(file_path, chunk_size)
         self.chunks_statuses = {}
         for i in range(self.number_of_chunks):
@@ -146,6 +148,7 @@ class _ChunksUploader:
         )
         try:
             headers = {
+                "X-Project": self._project_id,
                 "X-Api-Key": self._api_key,
                 "X-file-chunk": "{}/{}".format(chunk_number, self.number_of_chunks),
                 "X-file-hash": self._chunker.file_hash,
@@ -213,6 +216,7 @@ class Client:
     def upload(
         self,
         file_path: str,
+        project_id: int,
         chunk_size: int = DEFAULT_UPLOAD_CHUNK_SIZE,
         file_name: str = None,
         origin_dir_name: str = None,
@@ -231,7 +235,7 @@ class Client:
         ```origin_dir_name``` is a directory path (```dirA/dirB/dirC```). This path triggers
         the creation of the corresponding collections and sub-collections in Jama.
         """
-        upload_infos = self.upload_infos(_file_hash256(file_path))
+        upload_infos = self.upload_infos(_file_hash256(file_path), project_id=project_id)
         if upload_infos.get("status") == "available":
             raise AlreadyUploaded()
 
@@ -239,6 +243,7 @@ class Client:
             file_path,
             self._endpoint + "upload/partial/",
             self._api_key,
+            project_id,
             chunk_size,
             file_name,
             origin_dir_name,
